@@ -22,6 +22,7 @@
 */
 
 #include <config.h>
+#include <libgnome/gnome-i18n.h>
 
 #include <gnome.h>
 #include <bonobo.h>
@@ -37,8 +38,8 @@
 #include "gtkhtml-properties.h"
 #include "htmlsourceview.h"
 
-GtkWidget *control;
-gint formatHTML = 1;
+static GtkWidget *control;
+static gint formatHTML = 1;
 
 
 /* Saving/loading through PersistStream.  */
@@ -207,9 +208,13 @@ view_source_dialog (BonoboWindow *app, char *type, gboolean as_html)
 	BonoboWidget *control;
 	GtkWidget *window;
 	GtkWidget *view;
+	BonoboControlFrame *cf;
 
 	control = BONOBO_WIDGET (bonobo_window_get_contents (app));
 
+	cf = bonobo_widget_get_control_frame (BONOBO_WIDGET (control));
+	bonobo_control_frame_control_activate (cf);
+
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	view = html_source_view_new ();
 
@@ -218,7 +223,7 @@ view_source_dialog (BonoboWindow *app, char *type, gboolean as_html)
 	html_source_view_set_mode (HTML_SOURCE_VIEW (view), as_html);
 	gtk_widget_show_all (window);
 
-	g_signal_connect_swapped (control, "destroy", G_CALLBACK (g_object_unref), window);
+	g_signal_connect_swapped (control, "destroy", G_CALLBACK (gtk_widget_destroy), window);
 }    
 
 static void
@@ -242,6 +247,12 @@ view_html_source_html_cb (GtkWidget *widget,
 	view_source_dialog (data, "text/html", TRUE);
 }
 
+static void
+file_selection_cancel_cb (GtkWidget *widget, gpointer data)
+{
+	gtk_widget_destroy (GTK_WIDGET (data));
+}
+
 static void
 file_selection_ok_cb (GtkWidget *widget,
 		      gpointer data)
@@ -265,7 +276,7 @@ file_selection_ok_cb (GtkWidget *widget,
 		g_warning ("The Control does not seem to support `%s'.", interface_name);
 	} else 	 {
 		const gchar *fname;
-	
+
 		fname = gtk_file_selection_get_filename
 			(GTK_FILE_SELECTION (file_selection_info.widget));
 
@@ -320,8 +331,7 @@ open_or_save_as_dialog (BonoboWindow *app,
 	file_selection_info.control = control;
 	file_selection_info.operation = op;
 
-	g_signal_connect_object (GTK_FILE_SELECTION (widget)->cancel_button,
-				 "clicked", G_CALLBACK (gtk_widget_destroy), widget, G_CONNECT_AFTER);
+	g_signal_connect (GTK_FILE_SELECTION (widget)->cancel_button, "clicked", G_CALLBACK (file_selection_cancel_cb), widget);
 	g_signal_connect (GTK_FILE_SELECTION (widget)->ok_button, "clicked", G_CALLBACK (file_selection_ok_cb), NULL);
 	g_signal_connect (file_selection_info.widget, "destroy", G_CALLBACK (file_selection_destroy_cb), NULL);
 
@@ -374,6 +384,7 @@ exit_cb (GtkWidget *widget,
 	 gpointer data)
 {
 	gtk_widget_destroy (GTK_WIDGET (data));
+	bonobo_main_quit ();
 }
 
 
@@ -447,18 +458,11 @@ static char ui [] =
 "	</dockitem>"
 "</Root>";
 
-static void
-app_destroy_cb (GtkWidget *app, BonoboUIContainer *uic)
-{
-	bonobo_object_unref (BONOBO_OBJECT (uic));
-
-	bonobo_main_quit ();
-}
-
 static int
 app_delete_cb (GtkWidget *widget, GdkEvent *event, gpointer dummy)
 {
 	gtk_widget_destroy (GTK_WIDGET (widget));
+	bonobo_main_quit ();
 
 	return FALSE;
 }
@@ -481,8 +485,6 @@ container_create (void)
 
 	g_signal_connect (window, "delete_event", G_CALLBACK (app_delete_cb), NULL);
 
-	g_signal_connect (window, "destroy", G_CALLBACK (app_destroy_cb), container);
-
 	gtk_window_set_default_size (window, 600, 440);
 	gtk_window_set_resizable (window, TRUE);
 
@@ -502,6 +504,7 @@ container_create (void)
 	bonobo_ui_component_set_prop (component, "/commands/FormatHTML", "state", formatHTML ? "1" : "0", NULL);
 	bonobo_ui_component_add_listener (component, "FormatHTML", menu_format_html_cb, control);
 
+
 	bonobo_window_set_contents (BONOBO_WINDOW (win), control);
 
 	gtk_widget_show_all (GTK_WIDGET (window));
@@ -510,10 +513,20 @@ container_create (void)
 	engine = (GNOME_GtkHTML_Editor_Engine) Bonobo_Unknown_queryInterface
 		(bonobo_widget_get_objref (BONOBO_WIDGET (control)), "IDL:GNOME/GtkHTML/Editor/Engine:1.0", &ev);
 	GNOME_GtkHTML_Editor_Engine_runCommand (engine, "grab-focus", &ev);
-	Bonobo_Unknown_unref (engine, &ev);
-	CORBA_Object_release (engine, &ev);
+	bonobo_object_release_unref (engine, &ev);
 	CORBA_exception_free (&ev);
 
+	bonobo_widget_set_property (BONOBO_WIDGET (control),
+				    "MagicSmileys", TC_CORBA_boolean, TRUE,
+				    NULL);
+	bonobo_widget_set_property (BONOBO_WIDGET (control),
+				    "MagicLinks", TC_CORBA_boolean, TRUE,
+				    NULL);
+	bonobo_widget_set_property (BONOBO_WIDGET (control),
+				   "InlineSpelling", TC_CORBA_boolean, TRUE,
+				   NULL);
+
+
 	return FALSE;
 }
 
@@ -538,9 +551,12 @@ main (int argc, char **argv)
 {
 	bindtextdomain(GTKHTML_RELEASE_STRING, GNOMELOCALEDIR);
 	textdomain(GTKHTML_RELEASE_STRING);
-	
-	if (bonobo_ui_init ("test-gnome-gtkhtml-editor", "1.0", &argc, argv) == FALSE)
-		g_error ("Could not initialize Bonobo\n");
+
+	gnome_program_init("test-editor", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
+			   GNOME_PROGRAM_STANDARD_PROPERTIES,
+			   GNOME_PARAM_HUMAN_READABLE_NAME, _("GtkHTML Editor Test Container"),			   
+			   NULL);
+
 	bonobo_activate ();
 
 	/* We can't make any CORBA calls unless we're in the main loop.  So we
